@@ -8,22 +8,19 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * The contents of this file constitute Original Code as defined in and
+ * are subject to the Apple Public Source License Version 1.1 (the
+ * "License").  You may not use this file except in compliance with the
+ * License.  Please obtain a copy of the License at
+ * http://www.apple.com/publicsource and read it before using this file.
  * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
- * 
- * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This Original Code and all software distributed under the License are
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  *
@@ -185,7 +182,8 @@ void AppleDACAAudio::checkStatus(bool force)
     AudioHardwareDetect	*theDetect;
     OSArray 			*AudioDetects;
     UInt8 				currentStatusRegister = 0;
-    UInt32 				i ;
+    UInt32 				i;
+	UInt32				numDetects;
     bool				cachedHeadphonesInserted ;
 
     // get the value from the register
@@ -211,7 +209,8 @@ void AppleDACAAudio::checkStatus(bool force)
 		extdevices = 0;
         if(AudioDetects) 
         {
-            for(i = 0 ; i < AudioDetects->getCount() ; i++ ) 
+			numDetects = AudioDetects->getCount();
+            for(i = 0 ; i < numDetects ; i++ ) 
             {
                 theDetect = OSDynamicCast(AudioHardwareDetect, AudioDetects->getObject(i));
                 if (theDetect) 
