@@ -6,3 +6,10 @@
  *  Copyright (c) 2003 Apple. All rights reserved.
  *
  */
+
+#include "AppleOnyxAudio.h"
+#include "PlatformInterface.h"
+#include "AudioHardwareUtilities.h"
+
+
+
